import version as latest_vers

current_version = "1.0.1"
def check_update():
    if latest_vers.latest_version() != current_version:
        print("You are using old version. Please Update")
    else:
        pass


from setuptools import setup, find_packages

setup(
    name='3looyupd',
    version='1.0.0',
    packages=find_packages(),
    install_requires=[
        # No dependencies required
    ],
    author='3looybh',
    author_email='your_email@example.com',
    description='updating the app',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/3looybh/tools-downloader/',
    license='MIT',
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.8',
    ],
)
